# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingLeanBodyMassChangedEventType(str, enum.Enum):
    DAILY_DATA_LEAN_BODY_MASS_CREATED = "daily.data.lean_body_mass.created"
    DAILY_DATA_LEAN_BODY_MASS_UPDATED = "daily.data.lean_body_mass.updated"

    def visit(
        self,
        daily_data_lean_body_mass_created: typing.Callable[[], T_Result],
        daily_data_lean_body_mass_updated: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingLeanBodyMassChangedEventType.DAILY_DATA_LEAN_BODY_MASS_CREATED:
            return daily_data_lean_body_mass_created()
        if self is ClientFacingLeanBodyMassChangedEventType.DAILY_DATA_LEAN_BODY_MASS_UPDATED:
            return daily_data_lean_body_mass_updated()
